'use strict';
import { charCodes, classicCharCodes } from './mappings';
/**
 * @param strong if true, all characters will be converted to
 */
function mergeMappings(innerMappings, strong) {
    var base = {};
    var codes = !strong ? classicCharCodes : charCodes;
    for (var code in codes) {
        base[code] = codes[code];
    }
    if (innerMappings) {
        for (var mapping in innerMappings) {
            base[mapping] = innerMappings[mapping];
        }
    }
    return base;
}
function replacer(input, mappings) {
    return input
        .split('')
        .map(function (letter) {
        for (var mapping in mappings) {
            if (mapping &&
                mapping !== mappings[mapping] &&
                (mapping === letter || mappings[mapping].indexOf(letter) !== -1)) {
                letter = Array.isArray(mappings[mapping]) ? mappings[mapping].join('') : "[" + mappings[mapping] + "]";
                break;
            }
        }
        return letter;
    })
        .join('');
}
/** Generate a function that returns a RegExp, that can be reused with the same options */
export function toRegex(options, strong, spaces) {
    if (options === void 0) { options = {}; }
    var strongOption = strong === 'strong' ? true : false;
    var spaceOption = spaces === 'spaces' ? true : false;
    var innerMappings = mergeMappings(typeof options.mappings === 'object' ? options.mappings : null, strongOption);
    return function (input) {
        if (spaceOption) {
            input = input.replace(/\s/g, '').split('').join("(?:\\s|'|-)*");
        }
        else {
            input = input;
        }
        return new RegExp(replacer(input, innerMappings).replace(':\\[SsŚśŜŝŞşŠšȘșṠṡṢṣṤṥṦṧṨṩ]', ':\\s'), typeof options.flags === 'string' ? options.flags : 'i');
    };
}
//# sourceMappingURL=index.js.map